unit Unit1;

{$mode objfpc}{$H+}

interface

uses
  LCLTranslator, Classes, SysUtils, Forms, Controls, Graphics, Dialogs,
  StdCtrls, Spin, DateTimePicker;

type

  { TForm1 }

  TForm1 = class(TForm)
    btnToday: TButton;
    btnDateTimePicker: TButton;
    Button1: TButton;
    Button2: TButton;
    DateTimePicker1: TDateTimePicker;
    FloatSpinEdit1: TFloatSpinEdit;
    Label1: TLabel;
    RadioButton1: TRadioButton;
    RadioButton2: TRadioButton;
    procedure btnDateTimePickerClick(Sender: TObject);
    procedure btnTodayClick(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure RadioButton1Change(Sender: TObject);
    procedure RadioButton2Change(Sender: TObject);
  private
    procedure ChangeLanguage(ALang: String);
  public

  end;

var
  Form1: TForm1;

implementation

{$R *.lfm}

resourcestring
  RSTodayIs = 'Today is %s';
  RSTimeNow = 'Now it is %s';
  RSDateTimePickerDate = 'Date in DateTimePicker: %s';
  RSValueIs = 'The value is %s';

const
  FormatSettings_de: TFormatSettings = (
    CurrencyFormat: 1;
    NegCurrFormat: 5;
    ThousandSeparator: '.';
    DecimalSeparator: ',';
    CurrencyDecimals: 2;
    DateSeparator: '.';
    TimeSeparator: ':';
    ListSeparator: ';';
    CurrencyString: 'EUR';
    ShortDateFormat: 'd/m/yyyy';
    LongDateFormat: 'dddd, dd". "mmmm" "yyyy';
    TimeAMString: 'AM';
    TimePMString: 'PM';
    ShortTimeFormat: 'hh:nn';
    LongTimeFormat: 'hh:nn:ss';
    ShortMonthNames: ('Jan','Feb','Mär','Apr','Mai','Jun',
                      'Jul','Aug','Sep','Okt','Nov','Dez');
    LongMonthNames: ('Januar','Februar','März','April','Mai','Juni',
                     'Juli','August','September','Oktober','November','Dezember');
    ShortDayNames: ('So','Mo','Di','Mi','Do','Fr','Sa');
    LongDayNames: ('Sonntag','Montag','Dienstag','Mittwoch','Donnerstag','Freitag','Samstag');
    TwoDigitYearCenturyWindow: 50;
  );
  FormatSettings_en : TFormatSettings = (
    CurrencyFormat: 1;
    NegCurrFormat: 5;
    ThousandSeparator: ',';
    DecimalSeparator: '.';
    CurrencyDecimals: 2;
    DateSeparator: '-';
    TimeSeparator: ':';
    ListSeparator: ',';
    CurrencyString: '$';
    ShortDateFormat: 'mm/d/y';
    LongDateFormat: 'dddd", "mmmm dd", "yyyy';
    TimeAMString: 'AM';
    TimePMString: 'PM';
    ShortTimeFormat: 'hh:nn ampm';
    LongTimeFormat: 'hh:nn:ss ampm';
    ShortMonthNames: ('Jan','Feb','Mar','Apr','May','Jun',
                      'Jul','Aug','Sep','Oct','Nov','Dec');
    LongMonthNames: ('January','February','March','April','May','June',
                     'July','August','September','October','November','December');
    ShortDayNames: ('Sun','Mon','Tue','Wed','Thu','Fri','Sat');
    LongDayNames: ('Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday');
    TwoDigitYearCenturyWindow: 50;
  );

{ TForm1 }

procedure TForm1.ChangeLanguage(ALang: String);
begin
  SetDefaultLang(ALang);
  case ALang of
    'de': begin
            DefaultFormatSettings := FormatSettings_de;
            DateTimePicker1.DateDisplayOrder := ddoDMY;
            DateTimePicker1.DateSeparator := '.';
          end;
    'en': begin
            DefaultFormatSettings := FormatSettings_en;
            DateTimePicker1.DateDisplayOrder := ddoMDY;
            DateTimePicker1.DateSeparator := '/';
          end;
  end;
end;

procedure TForm1.btnTodayClick(Sender: TObject);
begin
  ShowMessage(Format(RSTodayIs, [FormatDateTime(DefaultFormatSettings.LongDateFormat, Now)]));
end;

procedure TForm1.Button1Click(Sender: TObject);
var
  t: TTime;
begin
  t := EncodeTime(18, 0, 30, 0);
//  t := Now();
  ShowMessage(Format(RSTimeNow, [TimeToStr(t)]));
end;

procedure TForm1.Button2Click(Sender: TObject);
begin
  ShowMessage(Format(RSValueIs, [FormatFloat('#0.00', FloatSpinEdit1.Value) + DefaultFormatSettings.CurrencyString]));
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  ChangeLanguage('de');
end;

procedure TForm1.btnDateTimePickerClick(Sender: TObject);
begin
  ShowMessage(Format(RSDateTimePickerDate, [DateToStr(DateTimePicker1.Date)]));
end;

procedure TForm1.RadioButton1Change(Sender: TObject);
begin
  if RadioButton1.Checked then
    ChangeLanguage('de');
end;

procedure TForm1.RadioButton2Change(Sender: TObject);
begin
  if RadioButton2.Checked then
    ChangeLanguage('en');
end;

end.

